@@ -1,7 +1,7 @@
 /*
-    ufiformat Version 0.9.8 2010/11/29
+    ufiformat Version 0.9.9 2011/01/29
 
-    Copyright (C) 2005-2010 Kazuhiro Hayashi <tedi@tedi.sakura.ne.jp>
+    Copyright (C) 2005-2011 Kazuhiro Hayashi <tedi@tedi.sakura.ne.jp>
     Copyright (C) 2005 John Floyd <jfloyd@bigpond.net.au>
 
     The method of formatting a floppy on USB-FDD used in this program
@@ -226,10 +226,10 @@ static int is_usb_fdd_for_host(int host_id)
     FILE *fp;
     struct stat st;
 
-    if (stat("/sys/class", &st) == 0) {
+    sprintf(path, "/sys/class/scsi_host/host%d/device/../driver", host_id);
+    if (stat(path, &st) == 0) {
 	int n;
 
-	sprintf(path, "/sys/class/scsi_host/host%d/device/../driver", host_id);
 	if ((n = readlink(path, buf, sizeof(buf))) < 12 || strncmp(buf + n - 12, "/usb-storage", 12) != 0) {
 	    return 0;
 	}
